@@ -7,8 +7,7 @@ use warnings;
 use strict;
 
 package XML::Compile;
-use vars '$VERSION';
-$VERSION = '1.41';
+our $VERSION = '1.43';
 
 
 use Log::Report 'xml-compile';
@@ -123,6 +122,9 @@ sub dataToXML($)
     elsif(-f $raw)
     {   ($xml, %details) = $thing->_parseFile($raw);
     }
+    elsif($raw !~ /[\n\r<]/ && $raw =~ m![/\\]|\.xsd$|\.wsdl!i)
+    {   error __x"file {fn} does not exist", fn => $fn;
+    }
     else
     {   my $data = "$raw";
         $data = substr($data, 0, 59) . '...' if length($data) > 60;
